@@ -17,31 +17,27 @@ from git.repo import Repo as GITRepo
 
 from smartparams.settings import RESOURCE_DIR
 
+with RESOURCE_DIR.joinpath('dictionary.json').open() as file:
+    DICTIONARY = json.load(file)
+
+PATTERNS = dict(
+    number=r'\d+',
+    hash=r'[a-zA-Z0-9]+',
+    uuid=r'\w{8}-\w{4}-\w{4}-\w{4}-\w{12}',
+    adjective=r'[a-zA-Z\-]+',
+    noun=r'[a-zA-Z\-]+',
+    year=r'\d{2}|\d{4}',
+    month=r'\d{1,2}',
+    day=r'\d{1,2}',
+    hour=r'\d{1,2}',
+    minute=r'\d{1,2}',
+    second=r'\d{1,2}',
+    microsecond=r'\d+',
+)
+
 
 class SmartLab:
-    PATTERNS = dict(
-        number=r'\d+',
-        hash=r'[a-zA-Z0-9]+',
-        uuid=r'\w{8}-\w{4}-\w{4}-\w{4}-\w{12}',
-        adjective=r'[a-zA-Z\-]+',
-        noun=r'[a-zA-Z\-]+',
-        year=r'\d{2}|\d{4}',
-        month=r'\d{1,2}',
-        day=r'\d{1,2}',
-        hour=r'\d{1,2}',
-        minute=r'\d{1,2}',
-        second=r'\d{1,2}',
-        microsecond=r'\d+',
-    )
-
-    def __init__(
-        self,
-        remote: str = 'origin',
-    ) -> None:
-        self._remote = remote
-
-        with RESOURCE_DIR.joinpath('dictionary.json').open() as file:
-            self._dictionary = json.load(file)
+    remote: str = 'origin'
 
     def new(
         self,
@@ -69,8 +65,8 @@ class SmartLab:
                     ),
                     hash=token_hex(16),
                     uuid=uuid.uuid4(),
-                    adjective=random.choice(self._dictionary['adjectives']),
-                    noun=random.choice(self._dictionary['nouns']),
+                    adjective=random.choice(DICTIONARY['adjectives']),
+                    noun=random.choice(DICTIONARY['nouns']),
                     year=date.year,
                     month=date.month,
                     day=date.day,
@@ -120,7 +116,7 @@ class SmartLab:
 
         DVCRepo(root_dir).pull(
             targets=str(target),
-            remote=remote or self._remote,
+            remote=remote or self.remote,
             force=force,
             recursive=recursive,
             jobs=jobs,
@@ -155,7 +151,7 @@ class SmartLab:
             targets=str(target),
             recursive=recursive,
             jobs=jobs,
-            remote=remote or self._remote,
+            remote=remote or self.remote,
             to_remote=sync,
         )
 
@@ -191,19 +187,17 @@ class SmartLab:
             git={remote.name: remote.url for remote in repo.remotes},
             branch=repo.active_branch.name,
             commit=repo.active_branch.commit.hexsha if repo.active_branch.is_valid() else None,
-            uncommited_files=[file.a_path for file in repo.index.diff(None)],
+            uncommited_files=[f.a_path for f in repo.index.diff(None)],
             untracted_files=repo.untracked_files,
             packages=[f'{package.key}=={package.version}' for package in pkg_resources.working_set],
         )
 
-    def _build_pattern(
-        self,
-        string: str,
-    ) -> str:
+    @staticmethod
+    def _build_pattern(string: str) -> str:
         offset = 0
         for match in re.finditer(r'{(?P<name>\w+)(?::.+?)?}', string):
             name = match.group('name')
-            replacement = rf'(?P<{name}>{self.PATTERNS[name]})'
+            replacement = rf'(?P<{name}>{PATTERNS[name]})'
             string = string[: match.start() + offset] + replacement + string[match.end() + offset :]
             offset += len(replacement) - (match.end() - match.start())
 
