@@ -32,6 +32,7 @@ from smartparams.exceptions import (
     ObjectNotRegistered,
     UnexpectedTypeOptionArguments,
 )
+from smartparams.lab import SmartLab
 from smartparams.register import SmartRegister
 from smartparams.utils.cli import (
     Arguments,
@@ -119,6 +120,7 @@ class Smart(Generic[T]):
     strict: bool = strutil.to_bool(os.getenv('SMARTPARAMS_STRICT', default='no'))
     debug: bool = strutil.to_bool(os.getenv('SMARTPARAMS_DEBUG', default='no'))
 
+    lab = SmartLab()
     __register = SmartRegister()
 
     def __init__(
@@ -507,6 +509,34 @@ class Smart(Generic[T]):
             missing_value=self.missing_value,
         )
 
+    def metadata(
+        self,
+        save_to: Optional[Path] = None,
+    ) -> Dict[str, Any]:
+        """Returns most important metadata of platform and project versions.
+
+        Args:
+            save_to: Path to save metadata.
+
+        Returns:
+            Dictionary with metadata.
+
+        """
+        metadata = dict(
+            **self.lab.metadata(),
+            params=self.representation(),
+        )
+
+        if save_to:
+            metadata_history = load_data(save_to) if save_to.exists() else dict()
+            metadata_history[f'run{len(metadata_history) + 1:03d}'] = metadata
+            save_data(
+                data=metadata_history,
+                path=save_to,
+            )
+
+        return metadata
+
     def run(
         self,
         function: Optional[Callable[['Smart'], Any]] = None,
@@ -741,7 +771,10 @@ class Smart(Generic[T]):
         skip_default: bool,
     ) -> Dict[str, Any]:
         representation: Dict[str, Any] = dict()
-        signature = inspect.signature(obj)
+        try:
+            signature = inspect.signature(obj)
+        except ValueError:
+            return representation
 
         for i, param in enumerate(signature.parameters.values()):
             name = param.name
