@@ -3,6 +3,8 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from unittest.mock import Mock, patch
 
+from git import Repo
+
 from smartparams.lab import SmartLab
 from tests.unit import UnitCase
 
@@ -111,8 +113,10 @@ class TestRegisterCase(UnitCase):
             self.assertFalse(directory.joinpath('folder1', 'filename.txt').exists())
             self.assertFalse(directory.joinpath('folder1.dvc').exists())
 
+    @patch('smartparams.lab.GITRepo')
     @patch('smartparams.lab.datetime', wraps=datetime)
     @patch('smartparams.lab.os.getlogin', Mock(return_value='user'))
+    @patch('smartparams.lab.sys', Mock(argv=['/script.py', 'arg1', 'arg2']))
     @patch('smartparams.lab.pkg_resources', Mock(working_set=[]))
     @patch('smartparams.lab.platform.node', Mock(return_value='node'))
     @patch('smartparams.lab.platform.platform', Mock(return_value='node'))
@@ -120,6 +124,7 @@ class TestRegisterCase(UnitCase):
     def test_metadata(
         self,
         datetime_mock: Mock,
+        git_repo: Mock,
     ) -> None:
         datetime_mock.now = Mock(return_value=datetime(2022, 4, 19, 1, 5, 14))
         expected = {
@@ -129,6 +134,8 @@ class TestRegisterCase(UnitCase):
             'host': 'node',
             'os': 'node',
             'python': 'python_version',
+            'script': '/script.py',
+            'args': ['arg1', 'arg2'],
             'git': {},
             'branch': 'master',
             'commit': None,
@@ -137,7 +144,7 @@ class TestRegisterCase(UnitCase):
             'packages': [],
         }
         with TemporaryDirectory() as dirname:
-            self.lab._git_root_dir = Path(dirname)
+            git_repo.return_value = Repo.init(dirname)
 
             actual = self.lab.metadata()
 
