@@ -3,21 +3,46 @@ from pathlib import Path
 from typing import Any, Dict, List, Tuple, Union
 from unittest.mock import Mock, patch
 
+from smartparams.exceptions import (
+    MissingArgument,
+    ObjectInvalidOptionError,
+    ObjectNotRegistered,
+    UnexpectedTypeOptionArguments,
+)
 from smartparams.smart import Smart
-from tests.custom_classes import Class, ClassChild
+from tests.custom_classes import Class, some_function
 from tests.unit import UnitCase
 
 
-class TestSmartInitCase(UnitCase):
+class TestSmart(UnitCase):
+    def test(self) -> None:
+        smart: Smart = Smart()
+
+        self.assertIs(smart.type, dict)
+
+    def test__class(self) -> None:
+        smart = Smart(Class)
+
+        self.assertIs(smart.type, Class)
+
+    def test__function(self) -> None:
+        smart = Smart(some_function)
+
+        self.assertIs(smart.type, None)
+
+    def test__lambda(self) -> None:
+        smart = Smart(lambda x: x)
+
+        self.assertIs(smart.type, Any)
+
+    def test__not_callable(self) -> None:
+        self.assertRaises(TypeError, Smart, 'not_callable')
+
+
+class TestSmartCallCase(UnitCase):
     def setUp(self) -> None:
         self.smart = Smart(Class, arg1='arg1', arg2=10)
 
-    def test_dict(self) -> None:
-        params = self.smart.dict
-
-        self.assertEqual(dict(arg1='arg1', arg2=10), params)
-        self.assertIsNot(self.smart._params, params)
-
     def test_call(self) -> None:
         obj = self.smart()
 
@@ -37,7 +62,7 @@ class TestSmartInitCase(UnitCase):
     def test_call__with_duplicated_dict(self) -> None:
         smart = Smart(Class, arg1='arg1')
 
-        self.assertRaises(TypeError, smart, 'a1')
+        self.assertRaises(MissingArgument, smart, 'a1')
 
     def test_call__without_class(self) -> None:
         smart: Smart = Smart()
@@ -47,10 +72,19 @@ class TestSmartInitCase(UnitCase):
         self.assertIsInstance(obj, dict)
 
 
-class TestSmartAccessCase(UnitCase):
+class TestSmartDictCase(UnitCase):
     def setUp(self) -> None:
         self.smart: Smart = Smart(arg1='arg1', arg2=['arg2'], arg3={'arg31': 'a31', 'arg32': 'a32'})
 
+    def test_dict(self) -> None:
+        expected = {'arg1': 'arg1', 'arg2': ['arg2'], 'arg3': {'arg31': 'a31', 'arg32': 'a32'}}
+
+        params = self.smart.dict
+
+        self.assertEqual(expected, params)
+        self.assertIsInstance(self.smart._params, dict)
+        self.assertIsNot(self.smart._params, params)
+
     def test_keys(self) -> None:
         keys = self.smart.keys()
 
@@ -196,7 +230,7 @@ class TestSmartAccessCase(UnitCase):
         self.assertRaises(TypeError, self.smart.update_from, source)
 
 
-class TestSmartInstantiateCase(UnitCase):
+class TestSmartInitCase(UnitCase):
     def setUp(self) -> None:
         self.class_name = f"{Class.__module__}.{Class.__qualname__}"
         self.params = dict(
@@ -208,6 +242,9 @@ class TestSmartInstantiateCase(UnitCase):
         )
         self.smart: Smart = Smart(**self.params)
 
+    def tearDown(self) -> None:
+        self.smart.register.reset()
+
     def test_init(self) -> None:
         obj = self.smart.init()
 
@@ -253,12 +290,12 @@ class TestSmartInstantiateCase(UnitCase):
     def test_init__type__raises(self) -> None:
         self.smart.set('type.argument', 10)
 
-        self.assertRaises(ValueError, self.smart.init, 'type')
+        self.assertRaises(UnexpectedTypeOptionArguments, self.smart.init, 'type')
 
     def test_init__unknown(self) -> None:
         self.smart.map('smart.class', lambda x: x + 'suffix')
 
-        self.assertRaises(ValueError, self.smart.init, 'smart')
+        self.assertRaises(ObjectInvalidOptionError, self.smart.init, 'smart')
 
     def test_init__object(self) -> None:
         result = self.smart.init('object')
@@ -267,8 +304,7 @@ class TestSmartInstantiateCase(UnitCase):
 
     def test_init__with_aliases(self) -> None:
         self.smart.allow_only_registered_classes = True
-        self.smart._aliases = {self.class_name: 'Class'}
-        self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
+        self.smart.register({self.class_name: 'Class'})
         self.smart.set('object.class', 'Class')
 
         result = self.smart.init('object')
@@ -276,8 +312,7 @@ class TestSmartInstantiateCase(UnitCase):
         self.assertIsInstance(result, Class)
 
     def test_init__with_aliases_not_used(self) -> None:
-        self.smart._aliases = {self.class_name: 'Class'}
-        self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
+        self.smart.register({self.class_name: 'Class'})
 
         result = self.smart.init('object')
 
@@ -285,82 +320,6 @@ class TestSmartInstantiateCase(UnitCase):
 
     def test_init__with_aliases_error(self) -> None:
         self.smart.allow_only_registered_classes = True
-        self.smart._aliases = {self.class_name: 'Class'}
-        self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
+        self.smart.register({self.class_name: 'Class'})
 
-        self.assertRaises(ImportError, self.smart.init, 'object')
-
-
-class TestRegisterCase(UnitCase):
-    def setUp(self) -> None:
-        self.smart = Smart
-        self.smart.strict = True
-
-    def tearDown(self) -> None:
-        self.smart._aliases = dict()
-        self.smart._origins = dict()
-
-    def test_register__classes(self) -> None:
-        classes = ('origin.1', 'origin.2')
-
-        self.smart.register(classes)
-
-        self.assertFalse(self.smart.allow_only_registered_classes)
-        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, self.smart._aliases)
-        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, self.smart._origins)
-
-    def test_register__with_prefix_with_class(self) -> None:
-        aliases = [Class, ClassChild]
-        expected_aliases = {
-            'tests.custom_classes.Class': 'some.classes.Class',
-            'tests.custom_classes.ClassChild': 'some.classes.ClassChild',
-        }
-        expected_origins = {
-            'some.classes.Class': 'tests.custom_classes.Class',
-            'some.classes.ClassChild': 'tests.custom_classes.ClassChild',
-        }
-
-        self.smart.register(aliases, prefix='some.classes')
-
-        self.assertFalse(self.smart.allow_only_registered_classes)
-        self.assertEqual(expected_aliases, self.smart._aliases)
-        self.assertEqual(expected_origins, self.smart._origins)
-
-    def test_register__aliases(self) -> None:
-        aliases = {'origin.1': 'alias.1', 'origin.2': 'alias.2'}
-
-        self.smart.register(aliases)
-
-        self.assertFalse(self.smart.allow_only_registered_classes)
-        self.assertEqual({'origin.1': 'alias.1', 'origin.2': 'alias.2'}, self.smart._aliases)
-        self.assertEqual({'alias.1': 'origin.1', 'alias.2': 'origin.2'}, self.smart._origins)
-
-    def test_register__alias_duplicates(self) -> None:
-        self.smart._aliases = {'origin': 'alias'}
-        self.smart._origins = {'alias': 'origin'}
-        aliases = {'origin.1': 'alias'}
-
-        self.assertRaises(ValueError, self.smart.register, aliases)
-
-    def test_register__origin_duplicates(self) -> None:
-        self.smart._aliases = {'origin': 'alias'}
-        self.smart._origins = {'alias': 'origin'}
-        aliases = {'origin': 'alias.1'}
-
-        self.assertRaises(ValueError, self.smart.register, aliases)
-
-    @patch('smartparams.utils.warnings')
-    def test_register__duplicates(self, warnings: Mock) -> None:
-        self.smart.strict = False
-        Smart._aliases = {'origin.1': 'alias.1', 'origin.2': 'alias.2'}
-        Smart._origins = {'alias.1': 'origin.1', 'alias.2': 'origin.2'}
-        aliases = {'origin.1': 'alias.2'}
-
-        self.smart.register(aliases)
-
-        self.assertEqual({'origin.1': 'alias.2'}, Smart._aliases)
-        self.assertEqual({'alias.2': 'origin.1'}, Smart._origins)
-        warnings.warn.assert_called()
-
-    def test_register__raise(self) -> None:
-        self.assertRaises(TypeError, self.smart.register, Mock())
+        self.assertRaises(ObjectNotRegistered, self.smart.init, 'object')
